.. :changelog:

Release History
---------------

0.1.1 (2019-08-16)
++++++++++++++++++

- Bugfix, Fixes bug around --index-url and --extra-index url in requirements.txt, lines would get removed.
- Bugfix, if a package version could not be found the version "None" would be assigned, the fix makes no version be assigned to that package.


0.1.0 (2019-02-06)
++++++++++++++++++

- Initial release.
